@@ -4,7 +4,7 @@ package AnyEvent::Filesys::Notify::Role::KQueue;
 
 use Moo::Role;
 use MooX::late;
-use namespace::sweep;
+use namespace::autoclean;
 use AnyEvent;
 use IO::KQueue;
 use Carp;
@@ -112,7 +112,7 @@ AnyEvent::Filesys::Notify::Role::KQueue - Use IO::KQueue to watch for changed fi
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 CONTRIBUTORS
 
@@ -125,7 +125,7 @@ Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2015 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
